@@ -10,6 +10,7 @@ import os
 from .utils.__player__ import play
 from .utils.__downloader__ import download
 from .utils.__cast__ import cast
+from .utils.__decryptor__ import decrypt_stream_url
 from .__version__ import __core__
 
 try:
@@ -17,9 +18,8 @@ try:
 except ImportError:
     import json
 
-import hashlib
 import sys
-from urllib.parse import urljoin, quote, urlencode, quote_plus
+from urllib.parse import urljoin, quote
 import time
 from bs4 import BeautifulSoup
 
@@ -39,67 +39,6 @@ DECODER = "https://dec.eatmynerds.live"
 selected_media = None
 selected_subtitles = []
 
-def urlencode_ordered(params, order):
-    # Encode query params in exact order
-    parts = []
-    for k in order:
-        v = params[k]
-        parts.append(f"{k}={quote_plus(str(v))}")
-    return "&".join(parts)
-
-def decrypt_stream_url(embed_link, api_url):
-    # Step 1: Get challenge info
-    resp = client.get(f"{api_url}/challenge")
-    if resp.status_code != 200:
-        print(f"Failed to fetch challenge ({resp.status_code})")
-        print(resp.text)
-        return embed_link, []
-
-    data = resp.json()
-    payload = data.get("payload")
-    signature = data.get("signature")
-    difficulty = int(data.get("difficulty", 0))
-    if not (payload and signature and difficulty):
-        print("Missing challenge data fields")
-        return embed_link, []
-
-    challenge = payload.split(".")[0]
-
-    prefix = "0" * difficulty
-    nonce = 0
-    while True:
-        text = f"{challenge}{nonce}"
-        hash_digest = hashlib.sha256(text.encode("utf-8")).hexdigest()
-        if hash_digest.startswith(prefix):
-            break
-        nonce += 1
-
-    # Step 3: Construct full URL manually with encoded params
-    query_params = {
-        "url": embed_link,
-        "payload": payload,
-        "signature": signature,
-        "nonce": nonce
-    }
-    ordered_query = urlencode_ordered(query_params, ['url', 'payload', 'signature', 'nonce'])
-    full_url = f"{api_url}?{ordered_query}"
-
-    final_resp = client.get(full_url)
-    if final_resp.status_code != 200:
-        print(f"Failed to get decrypted url from decoder ({final_resp.status_code})")
-        print(final_resp.text)
-        return embed_link, []
-
-    final_data = final_resp.json()
-    video_link = final_data.get("file") or ""
-    subtitles = []
-    if "tracks" in final_data:
-        for track in final_data["tracks"]:
-            if track.get("kind") == "captions" and track.get("file"):
-                subtitles.append(track["file"])
-
-    return video_link, subtitles
-
 def parse_episode_range(episode_input: str):
     """Parse episode input to handle ranges like '5-7' or single episodes like '5'"""
     episode_input = episode_input.strip()
@@ -174,7 +113,6 @@ def search_content(query: str):
         return None
 
 def get_tv_seasons(media_id: str):
-    """Get TV show seasons using lobster's approach"""
     try:
         seasons_url = f"{FLIXHQ_AJAX_URL}/v2/tv/seasons/{media_id}"
         response = client.get(seasons_url)
@@ -196,7 +134,6 @@ def get_tv_seasons(media_id: str):
         return []
 
 def get_season_episodes(season_id: str):
-    """Get episodes for a season using lobster's approach"""
     try:
         episodes_url = f"{FLIXHQ_AJAX_URL}/v2/season/episodes/{season_id}"
         response = client.get(episodes_url)
@@ -217,7 +154,6 @@ def get_season_episodes(season_id: str):
         return []
 
 def get_episode_servers(data_id: str, preferred_provider: str = "Vidcloud"):
-    """Get episode servers using lobster's approach"""
     try:
         servers_url = f"{FLIXHQ_AJAX_URL}/v2/episode/servers/{data_id}"
         response = client.get(servers_url)
@@ -242,7 +178,6 @@ def get_episode_servers(data_id: str, preferred_provider: str = "Vidcloud"):
         return None
 
 def get_embed_link(episode_id: str):
-    """Get embed link from episode sources endpoint"""
     try:
         sources_url = f"{FLIXHQ_AJAX_URL}/episode/sources/{episode_id}"
         response = client.get(sources_url)
@@ -430,7 +365,7 @@ def dlData(path: str = determine_path()):
         for i, episode_data in enumerate(episodes_to_download, 1):
             print(f"\nDownloading episode {i}/{len(episodes_to_download)}: {episode_data['label']}")
             try:
-                decoded_url, subs = decrypt_stream_url(episode_data['file'], DECODER)
+                decoded_url, subs = decrypt_stream_url(episode_data['file'])
                 if 'season' in episode_data and 'episode' in episode_data:
                     episode_query = f"{query}_S{episode_data['season']:02d}E{episode_data['episode']:02d}"
                 else:
@@ -453,7 +388,7 @@ def provideData(play_type):
         for i, episode_data in enumerate(episodes_to_play, 1):
             print(f"\nPlaying episode {i}/{len(episodes_to_play)}: {episode_data['label']}")
             try:
-                decoded_url, subs = decrypt_stream_url(episode_data['file'], DECODER)
+                decoded_url, subs = decrypt_stream_url(episode_data['file'])
 
                 if 'episode_title' in episode_data:
                      episode_title = episode_data['episode_title']
@@ -484,7 +419,7 @@ def provideData(play_type):
         print("No media selected for playback")
 
 def init():
-    ch = fzf_prompt(["play", "download", "chromecaast" "exit"])
+    ch = fzf_prompt(["play", "download", "chromecaast", "exit"])
     if ch == "play":
         provideData("play")
     elif ch == "download":
